@@ -1,15 +1,15 @@
 # @file EmpiricalCalibrationUsingAsymptotics.R
 #
-# Copyright 2015 Observational Health Data Sciences and Informatics
+# Copyright 2017 Observational Health Data Sciences and Informatics
 #
 # This file is part of EmpiricalCalibration
-# 
+#
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
-# 
+#
 #     http://www.apache.org/licenses/LICENSE-2.0
-# 
+#
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -76,7 +76,7 @@ fitNull <- function(logRr, seLogRr) {
     for (i in 1:length(estimate)) {
       result <- result - log(gaussianProduct(estimate[i], theta[1], se[i], exp(theta[2])))
     }
-    if (is.infinite(result))
+    if (length(result) == 0 || is.infinite(result))
       result <- 99999
     result
   }
@@ -161,7 +161,7 @@ calibrateP.null <- function(null, logRr, seLogRr, ...) {
 #'
 #' @description
 #' \code{computeTraditionalP} computes the traditional two-sided p-value based on the log of the
-#' relative risk and the standerd error of the log of the relative risk.
+#' relative risk and the standard error of the log of the relative risk.
 #'
 #' @param logRr     A numeric vector of one or more effect estimates on the log scale
 #' @param seLogRr   The standard error of the log of the effect estimates. Hint: often the standard
